@@ -18,8 +18,10 @@ extensions.append("sphinx.ext.intersphinx")
 # under RTD.
 target = join(dirname(__file__), "..", "docs", "_build")
 if on_rtd:
-    target = "http://docs.fabfile.org/en/latest/"
+    target = "https://docs.fabfile.org/en/latest/"
 intersphinx_mapping.update({"docs": (target, None)})
 
 # Sister-site links to API docs
-html_theme_options["extra_nav_links"] = {"API Docs": "http://docs.fabfile.org"}
+html_theme_options["extra_nav_links"] = {
+    "API Docs": "https://docs.fabfile.org"
+}
