@@ -1,4 +1,4 @@
-from mock import Mock, patch, call
+from unittest.mock import Mock, patch, call
 from pytest import mark, raises
 
 from fabric import Connection, Group, SerialGroup, ThreadingGroup, GroupResult
@@ -222,9 +222,7 @@ class ThreadingGroup_:
             ("start", Thread.return_value.start.call_count),
             ("join", Thread.return_value.join.call_count),
         ):
-            err = (
-                "Expected {} calls to ExceptionHandlingThread.{}, got {}"
-            )  # noqa
+            err = "Expected {} calls to ExceptionHandlingThread.{}, got {}"  # noqa
             err = err.format(expected, name, got)
             assert expected, got == err
 
