@@ -1,9 +1,6 @@
-try:
-    from invoke.vendor.six import StringIO
-except ImportError:
-    from six import StringIO
+from io import StringIO
 
-from mock import Mock, call, patch
+from unittest.mock import Mock, call, patch
 from pytest_relaxed import raises
 from pytest import skip  # noqa
 from paramiko import SFTPAttributes
